# IOD Parameters


::: py_outfit.iod_params.IODParams
        options:
          show_root_heading: true
          heading_level: 2
          members_order: source
          show_signature: true
          show_signature_annotations: true
          merge_init_into_class: true
          filters:
            - "!^_"


::: py_outfit.iod_params.IODParamsBuilder
        options:
          show_root_heading: true
          heading_level: 2
          members_order: source
          show_signature: true
          show_signature_annotations: true
          filters:
            - "!^_"
